@@ -1,4 +1,6 @@
 from pathfind.finder.alg.a_star import AStar
 from pathfind.finder.alg.breadth_first_search import BreadthFirstSearch, BFS
-from pathfind.finder.alg.greedy_best_first import GreedyBestFirst, Greedy
+from pathfind.finder.alg.d_star_lite import DStarLite
+from pathfind.finder.alg.depth_first_search import DepthFirstSearch, DFS
 from pathfind.finder.alg.dijkstra import Dijkstra
+from pathfind.finder.alg.greedy_best_first import GreedyBestFirst, Greedy
