@@ -1,12 +1,14 @@
-from pathfind.graph.graph import Graph
 from pathfind.finder import alg
 from pathfind.finder.finder import BaseFinder, GraphPath
+from pathfind.graph.graph import Graph
 
 METHOD_MAP = {
     "a*": alg.AStar,
     "bfs": alg.BFS,
     "greedy": alg.Greedy,
     "dijkstra": alg.Dijkstra,
+    "dfs": alg.DFS,
+    "d*lite": alg.DStarLite,
 }
 
 
