@@ -1,3 +1,3 @@
-from pathfind.graph.node import Node
-from pathfind.graph.edge import Edge
+from pathfind.graph.edge import Edge, get_edge_id, INFINITY
 from pathfind.graph.graph import Graph
+from pathfind.graph.node import Node
